texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[8349] split %misc_commands into two hashes


From: gavinsmith0123
Subject: [8349] split %misc_commands into two hashes
Date: Sat, 20 Oct 2018 06:51:42 -0400 (EDT)

Revision: 8349
          http://svn.sv.gnu.org/viewvc/?view=rev&root=texinfo&revision=8349
Author:   gavin
Date:     2018-10-20 06:51:42 -0400 (Sat, 20 Oct 2018)
Log Message:
-----------
split %misc_commands into two hashes

Modified Paths:
--------------
    trunk/ChangeLog
    trunk/tp/Texinfo/Common.pm

Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog     2018-10-20 10:29:54 UTC (rev 8348)
+++ trunk/ChangeLog     2018-10-20 10:51:42 UTC (rev 8349)
@@ -1,5 +1,11 @@
 2018-10-20  Gavin Smith  <address@hidden>
 
+       * tp/Texinfo/Common.pm (%misc_commands)
+       (%line_commands, %other_commands): Split %misc_commands into two 
+       hashes.
+
+2018-10-20  Gavin Smith  <address@hidden>
+
        * tp/Texinfo/Common.pm (%misc_commands):
        Change @insertcopying argument type from 'noarg' to 'skipline'.
        * NEWS: Mention this change and the warning for @multitable.

Modified: trunk/tp/Texinfo/Common.pm
===================================================================
--- trunk/tp/Texinfo/Common.pm  2018-10-20 10:29:54 UTC (rev 8348)
+++ trunk/tp/Texinfo/Common.pm  2018-10-20 10:51:42 UTC (rev 8349)
@@ -384,8 +384,6 @@
 # lineraw:     no value and macro expansion, the line is kept as-is, not 
 #              analysed
 # skipline:    no argument, everything else on the line is skipped
-# skipspace:   no argument, following spaces are skipped.
-# noarg:       no argument
 # text:        the line is parsed as texinfo, and the argument is converted
 #              to simple text (in _end_line)
 # line:        the line is parsed as texinfo
@@ -395,9 +393,9 @@
 #              The number is an indication of the number of arguments of 
 #              the command.
 #
-# Beware that @item and @itemx may be like 'line' or 'skipspace' depending
-# on the context.
-our %misc_commands = (
+# Beware that @item and @itemx may be 'line' commands or 'other' commands
+# depending on the context.
+our %line_commands = (
   'node'              => 'line', # special arg
   'bye'               => 'skipline', # no arg
   'end'               => 'text',
@@ -494,9 +492,29 @@
   'page'              => 'skipline', # no arg (pagebreak)
   'need'              => 1, # one numerical/real arg
   # formatting
-  'noindent'          => 'skipspace', # no arg
+  'exdent'            => 'line',
+  'item'              => 'line', # or skipspace, depending on the context
+  'itemx'             => 'line', # or skipspace, depending on the context
+  # not valid for info (should be in @iftex)
+  'vskip'             => 'lineraw', # arg line in TeX
+  # obsolete @-commands.
+  'setcontentsaftertitlepage'      => 'skipline', # no arg
+  'setshortcontentsaftertitlepage' => 'skipline', # no arg
+  # Remove spaces and end of lines after the 
+  # commands? If no, they can lead to empty lines
+  'quote-arg'         => 'skipline',
+  'allow-recursion'   => 'skipline',
+);
+
+# commands that do not take the whole line as argument
+#
+# skipspace:   no argument, following spaces are skipped.
+# noarg:       no argument
+#
+our %other_commands = (
+  # formatting
+  'noindent'          => 'skipspace',
   'indent'            => 'skipspace',
-  'exdent'            => 'line',
   'headitem'          => 'skipspace',
   'item'              => 'skipspace', # or line, depending on the context
   'itemx'             => 'skipspace', # or line, depending on the context
@@ -508,18 +526,12 @@
   'thisfile'          => 'noarg',
   'thispage'          => 'noarg',
   'thistitle'         => 'noarg',
-  # not valid for info (should be in @iftex)
-  'vskip'             => 'lineraw', # arg line in TeX
   # obsolete @-commands.
-  'refill'            => 'noarg',   # no arg (obsolete, to be ignored)
-  'setcontentsaftertitlepage'      => 'skipline', # no arg
-  'setshortcontentsaftertitlepage' => 'skipline', # no arg
-  # Remove spaces and end of lines after the 
-  # commands? If no, they can lead to empty lines
-  'quote-arg'         => 'skipline',
-  'allow-recursion'   => 'skipline',
+  'refill'            => 'noarg',
 );
 
+our %misc_commands = (%line_commands, %other_commands);
+
 our %index_names = (
  'cp' => {'in_code' => 0},
  'fn' => {'in_code' => 1},




reply via email to

[Prev in Thread] Current Thread [Next in Thread]